===================
terraformlintingcli
===================

A cli to lint and check file positioning for terraform resources


* Documentation: http://terraformlintingcli.readthedocs.io/en/latest/

Features
--------

* Lints terraform resources based on provided rules
* Enforces filename positioning for terraform resources based on provided rules
